
% FIG 3

% Simulate one-quantum-per-spike charge entry to the nulcear soma

% Create the shape of charge entry with a peak-and-tail signature of trans-
% membrane currrent, with an adjustable time constant. It is unnecessary to 
% also adjust peak amplitude because the functional relevance of changing 
% either is through the effect it has on the shape of the signature, and 
% and in particular the ratio of amplitude to time constant. 

opengl software
figure;

x = -0.7:0.05:20;

gaussian1 = @(x) (1/sqrt((2*pi))*exp(-x.^2/2))% a normal distribution
skewedgaussian1 = @(x,alpha) 2*gaussian1(x).*normcdf(alpha*x)% that normal 
% distribution skewed

g2_amplitude = .93; % amplitude - changing the amplitude doesn't change the rise 
% time to peak amplitude. amp is only used to compensate for an effect on
% amplitude of dur.
g2_SDproxy = 6; % duration coefficient - increasing the value increases the time 
% constant of skewedgaussian (by a diminishing ratio i.e. a linear increase 
% of time constant requires an exponential increase of SDproxy).

gaussian2 = @(x) ((1/sqrt((2*pi))*exp(-x.^2/g2_SDproxy))*g2_amplitude)% the same 
% distribution as gaussian1 but with SD adjusted by SDproxy
skewedgaussian2 = @(x,alpha) 2*gaussian2(x).*normcdf(alpha*x)% skewed

g3_amplitude = .9;
g3_SDproxy = 20;

gaussian3 = @(x) ((1/sqrt((2*pi))*exp(-x.^2/g3_SDproxy))*g3_amplitude)
skewedgaussian3 = @(x,alpha) 2*gaussian3(x).*normcdf(alpha*x)

g4_amplitude = .88;
g4_SDproxy = 44;

gaussian4 = @(x) ((1/sqrt((2*pi))*exp(-x.^2/g4_SDproxy))*g4_amplitude)
skewedgaussian4 = @(x,alpha) 2*gaussian4(x).*normcdf(alpha*x)

g5_amplitude = .88;
g5_SDproxy = 74;

gaussian5 = @(x) ((1/sqrt((2*pi))*exp(-x.^2/g5_SDproxy))*g5_amplitude)
skewedgaussian5 = @(x,alpha) 2*gaussian5(x).*normcdf(alpha*x)

% % plot(x, skewedgaussian1(x, 4))
% % hold on
% % % plot(x, gaussian1(x))
% % % plot(x, gaussian2(x))
% % % plot(x, gaussian3(x))
% % % plot(x, gaussian4(x))
% % % plot(x, gaussian5(x))
% % plot(x, skewedgaussian2(x, 4))
% % plot(x, skewedgaussian3(x, 4))
% % plot(x, skewedgaussian4(x, 4))
% % plot(x, skewedgaussian5(x, 4))

% DERIVE TIME CONSTANTS
g1_influxUnit = skewedgaussian1(x, 4); % an array of y values in the range for x, 
% set above, representing charge influx driven by a single spike
[M,I] = max(g1_influxUnit); % M is the peak value in array and I its index position
drop = M*.368; % a 63.2% reduction of M
[~,closestIndex] = min(abs(drop-g1_influxUnit(I:end))); % Finds the index position 
% of the nearest value to 'drop' in the array 'I:end'
g1_timeConstant = closestIndex/20 % There are 20 index positions per ms, so 
% dividing the distance (measured in index positions) between I and
% closestIndex by 20 gives the time interval between the peak value of
% the skewed distribution and a reduction by 63.2%

g2_influxUnit = skewedgaussian2(x, 4);
[M,I] = max(g2_influxUnit);
drop = M*.368;
[~,closestIndex] = min(abs(drop-g2_influxUnit(I:end)));
g2_timeConstant = closestIndex/20

g3_influxUnit = skewedgaussian3(x, 4);
[M,I] = max(g3_influxUnit);
drop = M*.368;
[~,closestIndex] = min(abs(drop-g3_influxUnit(I:end)));
g3_timeConstant = closestIndex/20

g4_influxUnit = skewedgaussian4(x, 4);
[M,I] = max(g4_influxUnit);
drop = M*.368;
[~,closestIndex] = min(abs(drop-g4_influxUnit(I:end)));
g4_timeConstant = closestIndex/20

g5_influxUnit = skewedgaussian5(x, 4);
[M,I] = max(g5_influxUnit);
drop = M*.368;
[~,closestIndex] = min(abs(drop-g5_influxUnit(I:end)));
g5_timeConstant = closestIndex/20

% SUMMARY
% Create an array of 4,000 zeros representing a time interval of 200 ms
% divided into twentieths of a ms. An array represents a single PC. More 
% exactly, it will be used to represent charge influx driven by spike input 
% from a single PC. At each index position, there is a probability, P, of
% an input spike. At a steady afferent rate, it is the same in all moments. 
% When there is a spike, 0 is replaced by 0.001 at that index position.  
% Assume a 1 ms refectory period. Call the array PC1. Call the first such 
% index position index1. Call the next index2, and so on. Next, add 
% 'influx' to PC1 at index positions index1:index1+(length(influx)-1).
% Then, repeat at index positions index2:index2+(length(influx)-1), etc.

% BLOCK OF 4 PANELS, THE FIRST PANEL SHOWING CURRENT DRIVEN BY A SINGLE PC 
% FIRING AT 10Hz WITH TIME CONSTANTS OF 1.15 ms, 2 ms, 4 ms, 6 ms and 8 ms,
% THE SECOND SHOWING THE SAME BUT FOR 20 Hz, THE THIRD 40 Hz AND THE FOURTH
% 60 Hz

%%% PANEL A %%%
Hz = 20; % PC firing rate
p = Hz/20000; % The probability of a spike in any moment (a moment being 
% 1/20th of a ms.

% g1 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

% subplot(4,1,1)
% x = 1:4400;
% plot(x,PC1,'o')
% xticks([0 500 1000 1500 2000 2500 3000 3500 4000])
% xticklabels([0 25 50 75 100 125 150 175 200])

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g1_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g1_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g1_influxUnit)-1)+g1_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

subplot(4,1,1)
x = 1:4400;
plot(x,PC1current_lowHz,'Color',([0 0 .6]),'LineWidth',1.4)
xlabel(''); ylabel('current'); title('1 PC, 20 Hz');
xlim([0 4400]); xticks([0 500 1000 1500 2000 2500 3000 3500 4000]); 
xticklabels([0 25 50 75 100 125 150 175 200])
ylim([0 2.5]); yticklabels([ ])
set(gca,'FontSize',10)

hold on

% g2 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g2_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g2_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g2_influxUnit)-1)+g2_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

plot(x,PC1current_lowHz,'Color',([1 .84 0]),'LineWidth',1.4)

% g3 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g3_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g3_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g3_influxUnit)-1)+g3_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

plot(x,PC1current_lowHz,'Color',([1 .5 .5]),'LineWidth',1.4)

% g4 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g4_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g4_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g4_influxUnit)-1)+g4_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

plot(x,PC1current_lowHz,'Color',([.42 .56 .14]),'LineWidth',1.4)

% g5 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g5_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g5_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g5_influxUnit)-1)+g5_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

plot(x,PC1current_lowHz,'Color',([.6 .6 .6]),'LineWidth',1.4)

%%% PANEL B %%%
Hz = 40; % PC firing rate
p = Hz/20000; % The probability of a spike in any moment (a moment being 
% 1/20th of a ms.

% g1 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g1_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g1_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g1_influxUnit)-1)+g1_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

subplot(4,1,2)
x = 1:4400;
plot(x,PC1current_lowHz,'Color',([0 0 .6]),'LineWidth',1.4)
xlabel(''); ylabel('current'); title('1 PC, 40 Hz');
xlim([0 4400]); xticks([0 500 1000 1500 2000 2500 3000 3500 4000]); 
xticklabels([0 25 50 75 100 125 150 175 200])
ylim([0 2.5]); yticklabels([ ])
set(gca,'FontSize',10)

hold on

% g2 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g2_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g2_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g2_influxUnit)-1)+g2_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

plot(x,PC1current_lowHz,'Color',([1 .84 0]),'LineWidth',1.4)

% g3 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g3_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g3_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g3_influxUnit)-1)+g3_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

plot(x,PC1current_lowHz,'Color',([1 .5 .5]),'LineWidth',1.4)

% g4 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g4_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g4_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g4_influxUnit)-1)+g4_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

plot(x,PC1current_lowHz,'Color',([.42 .56 .14]),'LineWidth',1.4)

% g5 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g5_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g5_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g5_influxUnit)-1)+g5_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

plot(x,PC1current_lowHz,'Color',([.6 .6 .6]),'LineWidth',1.4)

%%% PANEL C %%%
Hz = 60; % PC firing rate
p = Hz/20000; % The probability of a spike in any moment (a moment being 
% 1/20th of a ms.

% g1 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g1_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g1_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g1_influxUnit)-1)+g1_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

subplot(4,1,3)
x = 1:4400;
plot(x,PC1current_lowHz,'Color',([0 0 .6]),'LineWidth',1.4)
xlabel(''); ylabel('current'); title('1 PC, 60 Hz');
xlim([0 4400]); xticks([0 500 1000 1500 2000 2500 3000 3500 4000]); 
xticklabels([0 25 50 75 100 125 150 175 200])
ylim([0 2.5]); yticklabels([ ])
set(gca,'FontSize',10)

hold on

% g2 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g2_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g2_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g2_influxUnit)-1)+g2_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

plot(x,PC1current_lowHz,'Color',([1 .84 0]),'LineWidth',1.4)

% g3 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g3_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g3_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g3_influxUnit)-1)+g3_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

plot(x,PC1current_lowHz,'Color',([1 .5 .5]),'LineWidth',1.4)

% g4 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g4_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g4_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g4_influxUnit)-1)+g4_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

plot(x,PC1current_lowHz,'Color',([.42 .56 .14]),'LineWidth',1.4)

% g5 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g5_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g5_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g5_influxUnit)-1)+g5_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

plot(x,PC1current_lowHz,'Color',([.6 .6 .6]),'LineWidth',1.4)

%%% PANEL D %%%
Hz = 80; % PC firing rate
p = Hz/20000; % The probability of a spike in any moment (a moment being 
% 1/20th of a ms.

% g1 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g1_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g1_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g1_influxUnit)-1)+g1_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

subplot(4,1,4)
x = 1:4400;
plot(x,PC1current_lowHz,'Color',([0 0 .6]),'LineWidth',1.4)
xlabel(''); ylabel('current'); title('1 PC, 80 Hz');
xlim([0 4400]); xticks([0 500 1000 1500 2000 2500 3000 3500 4000]); 
xticklabels([0 25 50 75 100 125 150 175 200])
ylim([0 2.5]); yticklabels([ ])
set(gca,'FontSize',10)

hold on

% g2 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g2_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g2_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g2_influxUnit)-1)+g2_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

plot(x,PC1current_lowHz,'Color',([1 .84 0]),'LineWidth',1.4)

% g3 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g3_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g3_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g3_influxUnit)-1)+g3_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

plot(x,PC1current_lowHz,'Color',([1 .5 .5]),'LineWidth',1.4)

% g4 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g4_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g4_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g4_influxUnit)-1)+g4_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

plot(x,PC1current_lowHz,'Color',([.42 .56 .14]),'LineWidth',1.4)

% g5 PLOT
PC1spikes_lowHz = zeros([1 4400]);

for i = 1:4400
    r = rand;
    if r <= p
        PC1spikes_lowHz(i) = 1;
    end
end

PC1current_lowHz = zeros([1 4400]);

i = 1;
while i < 4400
    if i < length(PC1spikes_lowHz)-(length(g5_influxUnit)-1)
        if PC1spikes_lowHz(i) == 1
            PC1current_lowHz(i:i+length(g5_influxUnit)-1) = ...
                PC1current_lowHz(i:i+length(g5_influxUnit)-1)+g5_influxUnit;
            i = i + 2;
        else
            i = i + 1;
        end
    else
        i = i + 1;
    end
end

plot(x,PC1current_lowHz,'Color',([.6 .6 .6]),'LineWidth',1.4)
