
% FIG 3

% Simulate one-quantum-per-spike charge entry to the nulcear soma

% Create the shape of charge entry with a peak-and-tail signature of trans-
% membrane currrent, with an adjustable time constant. It is unnecessary to 
% also adjust peak amplitude because the functional relevance of changing 
% either is through the effect it has on the shape of the signature, and 
% and in particular the ratio of amplitude to time constant. 

opengl software
figure;

x = -0.7:0.05:10;

amp = .91; % amplitude - changing the amplitude doesn't change the rise 
% time to peak amplitude. amp is only used to compensate for an effect on
% amplitude of dur.
SDproxy = 20; % duration coefficient - increasing the value increases the time 
% constant of skewedgaussian (by a diminishing ratio i.e. a linear increase 
% of time constant requires an exponential increase of SDproxy).

gaussian1 = @(x) (1/sqrt((2*pi))*exp(-x.^2/2))% a normal distribution
skewedgaussian1 = @(x,alpha) 2*gaussian1(x).*normcdf(alpha*x)% that normal 
% distribution skewed

gaussian2 = @(x) ((1/sqrt((2*pi))*exp(-x.^2/SDproxy))*amp)% the same 
% distribution but with SD adjusted by SDproxy
skewedgaussian2 = @(x,alpha) 2*gaussian2(x).*normcdf(alpha*x)% skewed

plot(x, gaussian1(x))
hold on
plot(x, skewedgaussian1(x, 4))
plot(x, gaussian2(x))
plot(x, skewedgaussian2(x, 4))

% plot(x, skewedgaussian(x, -4))
% plot(x, skewedgaussian(x, 1))
% plot(x, skewedgaussian(x, -1))

influx = skewedgaussian2(x, 4) % an array of y values in the range for x, 
% set above, representing charge influx driven by a single spike

[M,I] = max(influx) % M is the peak value in array and I its index position

drop = M*.368 % a 63.2% reduction of M

[~,closestIndex] = min(abs(drop-influx(I:end))) % Finds the index position 
% of the nearest value to 'drop' in the array 'I:end'

timeConstant = closestIndex/20 % There are 20 index positions per ms, so 
% dividing the distance (measured in index positions) between I and
% closestIndex by 20 gives the time interval between the peak value of
% the skewed distribution and a reduction by 63.2%

% Summary
% Create an array of 4,000 zeros representing a time interval of 200 ms
% divided into twentieths of a ms. An array represents a single PC. More 
% exactly, it will be used to represent charge influx driven by spike input 
% from a single PC. At each index position, there is a probability, P, of
% an input spike. At a steady afferent rate, it is the same in all moments. 
% When there is a spike, 0 is replaced by 0.001 at that index position.  
% Assume a 1 ms refectory period. Call the array PC1. Call the first such 
% index position index1. Call the next index2, and so on. Next, add 
% 'influx' to PC1 at index positions index1:index1+(length(influx)-1).
% Then, repeat at index positions index2:index2+(length(influx)-1), etc.

% Step 1




